Home Knowledge Base CUDA Programming

CUDA Programming — NVIDIA's parallel computing platform that enables general-purpose computation on GPUs, leveraging thousands of cores for massive parallelism.

Execution Hierarchy

Basic Pattern

__global__ void add(float *a, float *b, float *c, int n) {
    int i = blockIdx.x * blockDim.x + threadIdx.x;
    if (i < n) c[i] = a[i] + b[i];
}
// Launch: add<<<numBlocks, threadsPerBlock>>>(a, b, c, n);

Memory Hierarchy

Performance Keys

CUDA powers the majority of GPU computing workloads from deep learning training to scientific simulation.

cuda programming basicsgpu threadcuda kernel

Explore 500+ Semiconductor & AI Topics

From EUV lithography to CUDA optimization — search the full knowledge base or chat with our AI assistant.